@@ -3,7 +3,7 @@ from dataclasses import dataclass
 
 import pandas as pd
 from pandas.io.sql import pandasSQL_builder
-from sqlalchemy import create_engine  # type: ignore
+from sqlalchemy import create_engine, text  # type: ignore
 
 from flytekit import current_context, kwtypes
 from flytekit.configuration import SerializationSettings
@@ -11,6 +11,7 @@ from flytekit.configuration.default_images import DefaultImages, PythonVersion
 from flytekit.core.base_sql_task import SQLTask
 from flytekit.core.python_customized_container_task import PythonCustomizedContainerTask
 from flytekit.core.shim_task import ShimTaskExecutor
+from flytekit.loggers import logger
 from flytekit.models import task as task_models
 from flytekit.models.security import Secret
 from flytekit.types.schema import FlyteSchema
@@ -23,6 +24,7 @@ class SQLAlchemyDefaultImages(DefaultImages):
         PythonVersion.PYTHON_3_8: "cr.flyte.org/flyteorg/flytekit:py3.8-sqlalchemy-",
         PythonVersion.PYTHON_3_9: "cr.flyte.org/flyteorg/flytekit:py3.9-sqlalchemy-",
         PythonVersion.PYTHON_3_10: "cr.flyte.org/flyteorg/flytekit:py3.10-sqlalchemy-",
+        PythonVersion.PYTHON_3_11: "cr.flyte.org/flyteorg/flytekit:py3.11-sqlalchemy-",
     }
 
 
@@ -125,14 +127,14 @@ class SQLAlchemyTaskExecutor(ShimTaskExecutor[SQLAlchemyTask]):
                 tt.custom["connect_args"][key] = value
 
         engine = create_engine(tt.custom["uri"], connect_args=tt.custom["connect_args"], echo=False)
-        print(f"Connecting to db {tt.custom['uri']}")
+        logger.info(f"Connecting to db {tt.custom['uri']}")
 
         interpolated_query = SQLAlchemyTask.interpolate_query(tt.custom["query_template"], **kwargs)
-        print(f"Interpolated query {interpolated_query}")
+        logger.info(f"Interpolated query {interpolated_query}")
         with engine.begin() as connection:
             df = None
             if tt.interface.outputs:
-                df = pd.read_sql_query(interpolated_query, connection)
+                df = pd.read_sql_query(text(interpolated_query), connection)
             else:
-                pandasSQL_builder(connection).execute(interpolated_query)
+                pandasSQL_builder(connection).execute(text(interpolated_query))
         return df
